Skip to contents

Initializes the log directory for the session. It creates a new directory if it does not exist.

Usage

init_log_dir(SE)

Arguments

SE

A list containing session information.

Value

Updates the logdir element in the SE list with the path to the log directory.

Examples

SE <- as.environment(list(session = list(token = "asdf")))
init_log_dir(SE)
#> 2026-07-05 18:22:43.15 Start: init_log_dir
#> 2026-07-05 18:22:43.15 Logdir: /tmp/RtmpYPSOwP/FastRet/asdf
dir.exists(SE$logdir)
#> [1] TRUE